import sys

from PyQt6.QtCore import QModelIndex, Qt
from PyQt6.QtGui import QPainter, QStandardItem, QStandardItemModel
from PyQt6.QtWidgets import (
    QApplication,
    QListView,
    QMainWindow,
    QPushButton,
    QStyle,
    QStyledItemDelegate,
    QStyleOptionViewItem,
    QVBoxLayout,
    QWidget,
)


class Delegate(QStyledItemDelegate):
    def __init__(self):
        QStyledItemDelegate.__init__(self)

    def paint(
        self, painter: QPainter, option: QStyleOptionViewItem, index: QModelIndex
    ):
        options = QStyleOptionViewItem(option)
        self.initStyleOption(options, index)
        if options.widget:
            style = options.widget.style()
        else:
            style = QApplication.style()
        style.drawControl(QStyle.ControlElement.CE_ItemViewItem, options, painter)

        text = index.data(Qt.ItemDataRole.UserRole)
        rect = option.rect
        font = painter.font()
        font.setPixelSize(16)
        font.setBold(True)
        painter.setFont(font)
        painter.drawText(
            rect,
            Qt.AlignmentFlag.AlignLeft,
            text,
        )


class MainWindow(QMainWindow):
    def __init__(self) -> None:
        QMainWindow.__init__(self)
        self.central_widget = QWidget()
        self.setCentralWidget(self.central_widget)
        self.main_layout = QVBoxLayout(self.central_widget)

        self.model = QStandardItemModel()
        self.view = QListView()
        self.view.setItemDelegate(Delegate())
        self.view.setModel(self.model)
        self.main_layout.addWidget(self.view)

        self.add_item_btn = QPushButton("Add Item")
        self.add_item_btn.clicked.connect(self.add_item)
        self.main_layout.addWidget(self.add_item_btn)

        self.show()

    def add_item(self) -> None:
        item = QStandardItem()
        item.setData(f"Item {self.model.rowCount()}", Qt.ItemDataRole.UserRole)
        self.model.appendRow([item])


if __name__ == "__main__":
    app = QApplication(sys.argv)
    main_window = MainWindow()
    sys.exit(app.exec())
